import logging
import logging.config
import os
import configparser
import sys

# 模块级别的变量，用于缓存日志记录器
_logger = None
# 确保 sys 模块中的 stdout 使用 UTF-8 编码
sys.stdout.reconfigure(encoding='utf-8')
def setup_logging():
    global _logger
    if _logger is not None:
        return _logger

    # 确保日志目录存在
    log_path = 'D:/automock/logs'
    if not os.path.exists(log_path):
        os.makedirs(log_path)

    # 使用 RawConfigParser 读取 logging.conf 文件，并显式指定编码为 UTF-8
    config = configparser.RawConfigParser()
    with open('logging.conf', 'r', encoding='utf-8') as config_file:
        config.read_file(config_file)

    # 使用 fileConfig 读取配置对象
    logging.config.fileConfig(config)

    # 获取根日志记录器
    _logger = logging.getLogger()
    return _logger



from DataRecorder import Recorder
from datetime import datetime
recorder = Recorder('order.csv')
def addData(data):
    orderno = data['resdata']['orderno']
    mobile =data['resdata']['mobile']
    province = data['resdata']['province']
    amount = data['resdata']['amount']
    orderTime = data['resdata']['orderTime']
    #status=1  #  充值中
    #statusname='充值中'
    status = data['status']
    statusname = data['statusname']
    pushstatus = data['pushstatus']
    pushtime = data['pushtime']
    # 获取当前时间
    chargetime = data['chargetime']

    finishtime = data['finishtime']


    #订单号,手机号,省份,金额,状态,状态,是否推送,订单时间,充值时间,完成时间,推送时间
    recorder.add_data((orderno,mobile,province,amount,status,statusname,pushstatus,orderTime,chargetime,finishtime,pushtime))
    recorder.record()




from flask import Flask
import logset
from recordJob import jobStart
import controller  # 导入 controller.py 文件
app = Flask(__name__)


# 设置日志
logger = logset.setup_logging()


# 初始化路由
controller.init_routes(app)
# 启动定时任务
jobStart()

def main():
    logger.info("Starting App")
    app.run(host='127.0.0.1', port=5000)

if __name__ == '__main__':
    main()










import time
from record import get_order
from excuteOrder import charge
import threading
import logset

# 记录连续失败的次数
failure_count = 0
MAX_FAILURES = 3

# 全局变量来跟踪 job 的运行状态
job_running = True

logger = logset.setup_logging()

def job():
    global failure_count, job_running
    try:
        order_data = get_order()
        if order_data:
            charge(order_data)
            failure_count = 0  # 重置失败计数器



    except Exception as e:
        failure_count += 1
        logger.error(f"Error in job: {e}", exc_info=True)
        if failure_count >= MAX_FAILURES:
            job_running = False
            # 停止定时任务
            global job_thread
            #job_thread.stop()
            #logger.info(f"失败 {failure_count} 次后 线程关闭 ----")

def run_job():
    global job_thread, job_running
    while job_running and not job_thread.stopped():
        job()
        if failure_count >= MAX_FAILURES:
            break
        time.sleep(10)

class StoppableThread(threading.Thread):
    def __init__(self, *args, **kwargs):
        super(StoppableThread, self).__init__(*args, **kwargs)
        self._stop_event = threading.Event()

    def stop(self):
        self._stop_event.set()

    def stopped(self):
        return self._stop_event.is_set()

def jobStart():
    # 启动定时任务线程
    global job_thread, job_running
    job_thread = StoppableThread(target=run_job)
    job_thread.daemon = True  # 设置为守护线程，主线程结束时自动退出
    job_thread.start()
    logger.info("线程启动 ----")

def jobRun():
    global job_running
    job_running = True
    logger.info("线程恢复 ----")

def jobPause():
    global job_running
    job_running = False
    logger.info("线程暂停 ----")







import requests
import configparser
import time

import logset
import recordData
import recordJob
from datetime import datetime
# 获取日志记录器
logger = logset.setup_logging()

# 读取配置文件
config = configparser.ConfigParser()
with open('config.ini', 'r', encoding='utf-8') as config_file:
    config.read_file(config_file)

# 获取 external_host 配置
external_host = config['DEFAULT']['external_host']
province = config['DEFAULT']['province']
channel_user = config['DEFAULT']['channel_user']

def get_order():
    url = f"{external_host}/datapay/openapi/feeautomock/getOrder"
    headers = {
        'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/x-www-form-urlencoded',
    }
    data = {
        'province': province,
        'timestmap': time.time() * 1000,
        'channel_user': channel_user
    }
    logger.info(url)
    logger.info(data)
    response = requests.post(url, headers=headers, data=data)
    logger.info(response)
    if response.status_code == 200:
        if(response.json().get('res')=='1'):
            logger.info("获取到订单")

            recordJob.jobPause()  # 一次只处理一单 。 暂停任务

            return response.json()
        else:
            logger.info("没有订单")
            return None


    else:
        logger.info(f"Error: {response.status_code}")
        return None


def push_order(order_data):
    url = f"{external_host}/datapay/openapi/feeautomock/result"
    headers = {
        'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
        'Accept': '*/*',
        'Connection': 'keep-alive',
        'Content-Type': 'application/x-www-form-urlencoded',
    }
    data = {
        'orderno': order_data['resdata']['orderno'],
        'timestmap': time.time() * 1000,
        'channel_user': channel_user
    }
    logger.info(url)
    logger.info(data)
    response = requests.post(url, headers=headers, data=data)
    logger.info({response})
    if response.status_code == 200:
        if(response.json().get('res')=='1'):
            logger.info("订单推送成功")
            recordJob.jobPause()  # 一次只处理一单 。 暂停任务
            order_data['pushstatus'] ='推送成功'
        else:
          logger.info("订单推送失败")
          order_data['pushstatus']='推送失败'

    else:
        logger.info(f"Error: {response.status_code}")
        order_data['pushstatus'] = '推送异常'

    current_time = datetime.now()
    formatted_time = current_time.strftime('%Y-%m-%d %H:%M:%S')
    order_data['pushtime'] = formatted_time
    recordData.addData(order_data)
    # 这里可以添加推送订单的逻辑
    logger.info(f"Pushing order: {order_data}")
    recordJob.jobRun()  # 恢复任务
    # 示例：假设有一个推送接口
    # push_url = 'http://example.com/push_order'
    # push_response = requests.post(push_url, json=order_data)
    # return push_response.json()




import configparser


def get_config_params():
    # 读取 config.ini 文件
    config = configparser.ConfigParser()
    config_file_path = 'config.ini'

    try:
        with open(config_file_path, 'r', encoding='utf-8') as config_file:
            config.read_file(config_file)

        config_params = dict(config['DEFAULT'])
        return config_params
    except FileNotFoundError:
        print(f"Error: {config_file_path} not found.")
        return {}
    except Exception as e:
        print(f"Error reading {config_file_path}: {e}")
        return {}


def get_job_status():
    # 这里假设 job_running 是一个全局变量，可以通过某种方式获取
    # 为了简化示例，我们使用一个固定的值
    # 实际应用中，可以通过某种机制（如文件、数据库等）来跟踪 job 的状态
    from recordJob import job_running
    return "Running" if job_running else "Stopped"
